%?mingw_package_header

%global mingw_build_win32 1
%global mingw_build_win64 1

Name:           mingw-gnutls
Version:        2.12.17
Release:        1%{?dist}
Summary:        MinGW GnuTLS TLS/SSL encryption library

License:        GPLv3+ and LGPLv2+
Group:          Development/Libraries
URL:            http://www.gnutls.org/
#Source0:        ftp://ftp.gnutls.org/pub/gnutls/gnutls-%{version}.tar.bz2
# We use the same source tarball as Fedora native package, which
# has the patent tainted SRP code removed.
Source0:        gnutls-%{version}-nosrp.tar.xz

BuildArch:      noarch

Patch1: gnutls-2.12.11-rpath.patch
Patch2: gnutls-2.8.6-link-libgcrypt.patch
# Remove nonexisting references from texinfo file
Patch3: gnutls-2.12.2-nosrp.patch
# Skip tests that are expected to fail on libgcrypt build
Patch4: gnutls-2.12.7-dsa-skiptests.patch
Patch5: gnutls-2.12.14-leak.patch

# MinGW-specific patches.
Patch1001:      gnutls-mingw-compile-fix.patch

BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-gcc-c++
BuildRequires:  mingw32-binutils
BuildRequires:  mingw32-libgpg-error
BuildRequires:  mingw32-libgcrypt
BuildRequires:  mingw32-libtasn1
BuildRequires:  mingw32-gettext
BuildRequires:  mingw32-win-iconv
BuildRequires:  mingw32-readline
BuildRequires:  mingw32-zlib
BuildRequires:  mingw32-p11-kit

BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-gcc-c++
BuildRequires:  mingw64-binutils
BuildRequires:  mingw64-libgpg-error
BuildRequires:  mingw64-libgcrypt
BuildRequires:  mingw64-libtasn1
BuildRequires:  mingw64-gettext
BuildRequires:  mingw64-win-iconv
BuildRequires:  mingw64-readline
BuildRequires:  mingw64-zlib
BuildRequires:  mingw64-p11-kit

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool

# Yes, really ...
BuildRequires:  pkgconfig

# For native /usr/bin/msgfmt etc.
BuildRequires:  gettext


%description
GnuTLS TLS/SSL encryption library.  This library is cross-compiled
for MinGW.


# Win32
%package -n mingw32-gnutls
Summary:        MinGW GnuTLS TLS/SSL encryption library
Requires:       pkgconfig

%description -n mingw32-gnutls
GnuTLS TLS/SSL encryption library.  This library is cross-compiled
for MinGW.

# Win64
%package -n mingw64-gnutls
Summary:        MinGW GnuTLS TLS/SSL encryption library
Requires:       pkgconfig

%description -n mingw64-gnutls
GnuTLS TLS/SSL encryption library.  This library is cross-compiled
for MinGW.


%?mingw_debug_package


%prep
%setup -q -n gnutls-%{version}

%patch1 -p1 -b .rpath
%patch2 -p1 -b .link
%patch3 -p1 -b .nosrp
%patch4 -p1 -b .dsa-skiptests
%patch5 -p1 -b .leak

%patch1001 -p0 -b .mingw_compile

for i in auth_srp_rsa.c auth_srp_sb64.c auth_srp_passwd.c auth_srp.c gnutls_srp.c ext_srp.c; do
    touch lib/$i
done

%if 0%{?fedora} > 10
libtoolize --force --copy
aclocal
autoreconf
%endif


%build
%mingw_configure                   \
    --with-libtasn1-prefix=%{_prefix} \
    --with-included-libcfg         \
    --disable-srp-authentication   \
    --disable-static               \
    --disable-nls                  \
    --with-libgcrypt
# %{?_smp_mflags} doesn't build correctly.
%mingw_make
cp lib/COPYING COPYING.LIB


%install
%mingw_make_install DESTDIR=$RPM_BUILD_ROOT

# Remove .la files
rm -f $RPM_BUILD_ROOT%{mingw32_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{mingw64_libdir}/*.la

# The .def files aren't interesting for other binaries
rm -f $RPM_BUILD_ROOT%{mingw32_bindir}/*.def
rm -f $RPM_BUILD_ROOT%{mingw64_bindir}/*.def

# Remove info and man pages which duplicate stuff in Fedora already.
rm -rf $RPM_BUILD_ROOT%{mingw32_infodir}
rm -rf $RPM_BUILD_ROOT%{mingw32_mandir}

rm -rf $RPM_BUILD_ROOT%{mingw64_infodir}
rm -rf $RPM_BUILD_ROOT%{mingw64_mandir}


%files -n mingw32-gnutls
%doc COPYING COPYING.LIB
%{mingw32_bindir}/certtool.exe
%{mingw32_bindir}/gnutls-cli-debug.exe
%{mingw32_bindir}/gnutls-cli.exe
%{mingw32_bindir}/gnutls-serv.exe
%{mingw32_bindir}/libgnutls-26.dll
%{mingw32_bindir}/libgnutls-extra-26.dll
%{mingw32_bindir}/libgnutls-openssl-27.dll
%{mingw32_bindir}/libgnutlsxx-27.dll
%{mingw32_bindir}/p11tool.exe
%{mingw32_bindir}/psktool.exe
%{mingw32_libdir}/libgnutls-extra.dll.a
%{mingw32_libdir}/libgnutls-openssl.dll.a
%{mingw32_libdir}/libgnutls.dll.a
%{mingw32_libdir}/libgnutlsxx.dll.a
%{mingw32_libdir}/pkgconfig/gnutls-extra.pc
%{mingw32_libdir}/pkgconfig/gnutls.pc
%{mingw32_includedir}/gnutls/

%files -n mingw64-gnutls
%doc COPYING COPYING.LIB
%{mingw64_bindir}/certtool.exe
%{mingw64_bindir}/gnutls-cli-debug.exe
%{mingw64_bindir}/gnutls-cli.exe
%{mingw64_bindir}/gnutls-serv.exe
%{mingw64_bindir}/libgnutls-26.dll
%{mingw64_bindir}/libgnutls-extra-26.dll
%{mingw64_bindir}/libgnutls-openssl-27.dll
%{mingw64_bindir}/libgnutlsxx-27.dll
%{mingw64_bindir}/p11tool.exe
%{mingw64_bindir}/psktool.exe
%{mingw64_libdir}/libgnutls-extra.dll.a
%{mingw64_libdir}/libgnutls-openssl.dll.a
%{mingw64_libdir}/libgnutls.dll.a
%{mingw64_libdir}/libgnutlsxx.dll.a
%{mingw64_libdir}/pkgconfig/gnutls-extra.pc
%{mingw64_libdir}/pkgconfig/gnutls.pc
%{mingw64_includedir}/gnutls/


%changelog
* Thu Mar 29 2012 Michael Cronenworth <mike@cchtml.com> - 2.12.17-1
- New upstream version.
- Use system libtasn1.

* Sun Mar 11 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.12.14-7
- Added win64 support
- Dropped .def files

* Fri Mar 09 2012 Kalev Lember <kalevlember@gmail.com> - 2.12.14-6
- Remove .la files

* Wed Mar 07 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.12.14-5
- Renamed the source package to mingw-gnutls (RHBZ #800878)
- Use mingw macros without leading underscore
- Dropped unneeded RPM tags

* Tue Feb 28 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.12.14-4
- Rebuild against the mingw-w64 toolchain
- Fix compatibility with mingw-w64

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.12.14-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sat Dec 03 2011 Michael Cronenworth <mike@cchtml.com> - 2.12.14-2
- Include new tool from p11-kit support.

* Sat Dec 03 2011 Michael Cronenworth <mike@cchtml.com> - 2.12.14-1
- Update to 2.12.14
- Allow p11-kit support.

* Wed Nov 02 2011 Michael Cronenworth <mike@cchtml.com> - 2.12.12-1
- Update to 2.12.12

* Mon Oct 24 2011 Michael Cronenworth <mike@cchtml.com> - 2.12.11-1
- Update to 2.12.11

* Wed Jul 06 2011 Kalev Lember <kalevlember@gmail.com> - 2.10.5-2
- Rebuilt against win-iconv

* Thu Apr 28 2011 Kalev Lember <kalev@smartlink.ee> - 2.10.5-1
- Update to 2.10.5

* Wed Apr 27 2011 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.6.4-7
- Dropped the proxy-libintl pieces

* Fri Apr 22 2011 Kalev Lember <kalev@smartlink.ee> - 2.6.4-6
- Rebuilt for pseudo-reloc version mismatch (#698827)

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.6.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Nov  7 2010 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.6.4-4
- Rebuild in order to have soft dependency on libintl

* Fri Oct  9 2009 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.6.4-3
- Use %%global instead of %%define
- Automatically generate debuginfo subpackage

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.6.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Mar  9 2009 Richard W.M. Jones <rjones@redhat.com> - 2.6.4-1
- New Fedora native version 2.6.4.

* Fri Feb 20 2009 Richard W.M. Jones <rjones@redhat.com> - 2.6.3-5
- Rebuild for mingw32-gcc 4.4

* Thu Feb 19 2009 Richard W.M. Jones <rjones@redhat.com> - 2.6.3-4
- +BR mingw32-gcc-c++

* Fri Feb  6 2009 Richard W.M. Jones <rjones@redhat.com> - 2.6.3-3
- Include license.

* Fri Jan 23 2009 Richard W.M. Jones <rjones@redhat.com> - 2.6.3-2
- Rebase to native Fedora version 2.6.3.
- Enable C++ library.
- Use find_lang macro.
- Don't build static library.
- Rebase MinGW patch to 2.6.3.
- +BR mingw32-dlfcn.
- +BR mingw32-readline.
- Force rebuild of libtool.

* Tue Jan 13 2009 Richard W.M. Jones <rjones@redhat.com> - 2.4.2-4
- Requires pkgconfig.

* Thu Nov 13 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.2-3
- fix chain verification issue CVE-2008-4989 (#470079)
- separate out the MinGW-specific patch from the others

* Wed Sep 24 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.2-2
- Rename mingw -> mingw32.

* Wed Sep 24 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.2-1
- New native version.

* Mon Sep 22 2008 Daniel P. Berrange <berrange@redhat.com> - 2.4.1-9
- Switch to source tar.bz2 with SRP stuff removed

* Sun Sep 21 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.1-8
- Remove duplicate manpages and info files.

* Thu Sep 11 2008 Daniel P. Berrange <berrange@redhat.com> - 2.4.1-7
- Add BR on autoconf, automake and libtool

* Wed Sep 10 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.1-6
- Need to run autoreconf after patching src/Makefile.am.
- Remove static libs.

* Fri Sep  5 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.1-5
- Add patch to build certtool.exe because of missing dep of gnulib on intl.
- BuildArch is noarch.

* Thu Sep  4 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.1-3
- Use mingw-filesystem RPM macros.
- Depends on mingw-iconv, mingw-gettext.

* Tue Sep  2 2008 Daniel P. Berrange <berrange@redhat.com> - 2.4.1-2
- List files explicitly and use custom CFLAGS

* Mon Jul  7 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.1-1
- Initial RPM release, largely based on earlier work from several sources.
